@@ -65,8 +65,8 @@ class Customer(MuviBase):
         self.headers['apikey'] = self.private_key
         formatted_client['id'] = r.json()['id']
         if r.status_code > 400:
-            return self.error(r.json(), status=r.status_code)
-        return self.ok(formatted_client, status=r.status_code)
+            return self.error(response=r.json(), status=r.status_code)
+        return self.ok(response=formatted_client, status=r.status_code)
 
     def get(self, customer_id: str) -> dict:
         # No existen los datos del customer almacenados en decidir
