@@ -51,6 +51,7 @@ map_errors = {
 }
 arg_tz = pytz.timezone('America/Buenos_Aires')
 
+
 def _format_card(response):
     if 'card' in response:
         return {
@@ -148,8 +149,8 @@ class Payment(MuviBase):
             'payment_type': 'single',
             'establishment_name': self.merchant_name,
             'sub_payments': [],
-            'amount':total_amount, # En cualquier tipo de payment
-            'installments':installments,
+            'amount': total_amount, # En cualquier tipo de payment
+            'installments': installments,
         }
         if 'application_fee' in payment_data and self.marketplace:
             application_fee = round(payment_data['application_fee'], 2) * 100
@@ -183,8 +184,8 @@ class Payment(MuviBase):
         if 'status' in response and 'site_transaction_id' in response:
             if 'card' in payment_data:
                 response['card'] = payment_data['card']
-            return self.ok(_format(response))
-        return self.error(response, status=r.status_code)
+            return self.ok(response=_format(response))
+        return self.error(response=response, status=r.status_code)
 
     def get(self, payment_id: str):
         filters = {
@@ -194,7 +195,7 @@ class Payment(MuviBase):
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
         list_results = r.json()['results']
         if len(list_results) == 1:
-            return self.ok(_format(list_results[0]), status=r.status_code)
+            return self.ok(response=_format(list_results[0]), status=r.status_code)
         else:
             return self.error(message='error_pago_no_encontrado', status=r.status_code)
 
@@ -210,8 +211,8 @@ class Payment(MuviBase):
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
         response = r.json()
         response['results'] = [_format(r) for r in response['results']]
-        return self.ok(response, status=r.status_code)
+        return self.ok(response=response, status=r.status_code)
 
     def get_payment_methods(self):
         r = requests.get(self.url + '/payment-methods/1', headers=self.headers)
-        return self.ok(r.json(), status=r.status_code)
+        return self.ok(response=r.json(), status=r.status_code)
