@@ -18,7 +18,7 @@ class CardToken(MuviBase):
         card_token_response = self.sdk.card_token().create(data)
 
         if card_token_response['status'] > 299:
-            return self.error(card_token_response['response'], status=card_token_response['status'])
+            return self.error(response=card_token_response['response'], status=card_token_response['status'])
 
         # Para estandarizar la response con decidir
         if 'first_six_digits' in card:
@@ -29,4 +29,4 @@ class CardToken(MuviBase):
         for f in ['last_four_digits', 'expiration_month', 'expiration_year', 'cardholder']:
             card_token_response['response'][f] = card[f] if f in card else None
 
-        return self.ok(card_token_response['response'], status=card_token_response['status'])
+        return self.ok(response=card_token_response['response'], status=card_token_response['status'])
